@@ -7,7 +7,13 @@
 #ifdef HAVE_RUBYSIG_H
 # include "rubysig.h"
 #endif
+
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#else
+#include <io.h>
+#endif
+
 #include <fcntl.h>
 #include <assert.h>
 
@@ -291,6 +297,11 @@ static VALUE NIO_Selector_select_synchronized(VALUE *args)
     struct NIO_Selector *selector;
 
     Data_Get_Struct(args[0], struct NIO_Selector, selector);
+
+    if(selector->closed) {
+        rb_raise(rb_eIOError, "selector is closed");
+    }
+
     if(!rb_block_given_p()) {
         selector->ready_array = rb_ary_new();
     }
