@@ -13,11 +13,21 @@ module NIO
           io = io.to_io
         end
 
-        raise TypeError, "can't convert #{io.class} into IO" unless io.is_a? IO
+        fail TypeError, "can't convert #{io.class} into IO" unless io.is_a? IO
       end
 
-      @io, @interests, @selector = io, interests, selector
-      @closed = false
+      @io        = io
+      @interests = interests
+      @selector  = selector
+      @closed    = false
+    end
+
+    # set the interests set
+    def interests=(interests)
+      fail TypeError, "monitor is already closed" if closed?
+      fail ArgumentError, "bad interests: #{interests}" unless [:r, :w, :rw].include?(interests)
+
+      @interests = interests
     end
 
     # Is the IO object readable?
@@ -29,10 +39,12 @@ module NIO
     def writable?
       readiness == :w || readiness == :rw
     end
-    alias_method :writeable?, :writable?
+    alias writeable? writable?
 
     # Is this monitor closed?
-    def closed?; @closed; end
+    def closed?
+      @closed
+    end
 
     # Deactivate this monitor
     def close(deregister = true)
