@@ -1,6 +1,6 @@
-require 'spec_helper'
+require "spec_helper"
 
-describe "NIO acceptables" do
+RSpec.describe "NIO acceptables" do
   shared_context "an NIO acceptable" do
     let(:selector) { NIO::Selector.new }
 
@@ -15,7 +15,7 @@ describe "NIO acceptables" do
   end
 
   describe TCPServer do
-    let(:tcp_port) { 23456 }
+    let(:tcp_port) { 23_456 }
 
     let :acceptable_subject do
       server = TCPServer.new("localhost", tcp_port)
