@@ -1,20 +1,20 @@
-require 'spec_helper'
-require 'openssl'
+require "spec_helper"
+require "openssl"
 
-describe OpenSSL::SSL::SSLSocket, :if => RUBY_VERSION >= "1.9.0" do
-  let(:tcp_port) { 34567 }
+RSpec.describe OpenSSL::SSL::SSLSocket, if: RUBY_VERSION >= "1.9.0" do
+  let(:tcp_port) { 34_567 }
 
   let(:ssl_key) { OpenSSL::PKey::RSA.new(1024) }
 
   let(:ssl_cert) do
-    name = OpenSSL::X509::Name.new([%w[CN localhost]])
+    name = OpenSSL::X509::Name.new([%w(CN localhost)])
     OpenSSL::X509::Certificate.new.tap do |cert|
       cert.version = 2
       cert.serial = 1
       cert.issuer = name
       cert.subject = name
       cert.not_before = Time.now
-      cert.not_after = Time.now + (365 * 24 *60 *60)
+      cert.not_after = Time.now + (365 * 24 * 60 * 60)
       cert.public_key = ssl_key.public_key
 
       cert.sign(ssl_key, OpenSSL::Digest::SHA1.new)
@@ -114,8 +114,8 @@ describe OpenSSL::SSL::SSLSocket, :if => RUBY_VERSION >= "1.9.0" do
       expect(count).not_to eq(0)
     rescue IO::WaitReadable, IO::WaitWritable
       pending "SSL will report writable but not accept writes"
-      raise if(writers.include? ssl_client)
-    end while writers and writers.include? ssl_client
+      raise if writers.include? ssl_client
+    end while writers && writers.include?(ssl_client)
 
     # I think the kernel might manage to drain its buffer a bit even after
     # the socket first goes unwritable. Attempt to sleep past this and then
@@ -124,15 +124,15 @@ describe OpenSSL::SSL::SSLSocket, :if => RUBY_VERSION >= "1.9.0" do
 
     # Once more for good measure!
     begin
-#        ssl_client.write_nonblock "X" * 1024
+      #        ssl_client.write_nonblock "X" * 1024
       loop { ssl_client.write_nonblock "X" * 1024 }
     rescue OpenSSL::SSL::SSLError
     end
 
     # Sanity check to make sure we actually produced an unwritable socket
-#      if select([], [ssl_client], [], 0)
-#        pending "Failed to produce an unwritable socket"
-#      end
+    #      if select([], [ssl_client], [], 0)
+    #        pending "Failed to produce an unwritable socket"
+    #      end
 
     ssl_client
   end
