@@ -1,11 +1,12 @@
-require 'spec_helper'
+require "spec_helper"
+require "timeout"
 
 # Timeouts should be at least this precise (in seconds) to pass the tests
 # Typical precision should be better than this, but if it's worse it will fail
 # the tests
 TIMEOUT_PRECISION = 0.1
 
-describe NIO::Selector do
+RSpec.describe NIO::Selector do
   let(:pair)   { IO.pipe }
   let(:reader) { pair.first }
   let(:writer) { pair.last }
@@ -115,9 +116,19 @@ describe NIO::Selector do
   end
 
   context "select" do
+    it "does not block on super small precision intervals" do
+      wait_interval = 1e-4
+
+      expect do
+        Timeout.timeout(2) do
+          subject.select(wait_interval)
+        end
+      end.not_to raise_error
+    end
+
     it "selects IO objects" do
       writer << "ohai"
-      unready, _ = IO.pipe
+      unready = IO.pipe.first
 
       reader_monitor  = subject.register(reader, :r)
       unready_monitor = subject.register(unready, :r)
@@ -147,7 +158,7 @@ describe NIO::Selector do
       readable2, writer = IO.pipe
       writer << "ohai"
 
-      unreadable, _ = IO.pipe
+      unreadable = IO.pipe.first
 
       monitor1 = subject.register(readable1, :r)
       monitor2 = subject.register(readable2, :r)
@@ -161,6 +172,12 @@ describe NIO::Selector do
       expect(readables).to include monitor2
       expect(readables).not_to include monitor3
     end
+
+    it "raises IOError if asked to select on a closed selector" do
+      subject.close
+
+      expect { subject.select(0) }.to raise_exception IOError
+    end
   end
 
   it "closes" do
